@@ -28,6 +28,12 @@ class Vector2:
         """return a tuple of the vector"""
         return (self.x,self.y)
     
+    def __add__(self,other):
+        if type(other)==Vector2:
+            return Vector2(self.x + other.x, self.y + other.y)
+        else:
+            raise TypeError("You can just add Vector2 between them but you pass :", type(other))
+    
     def copy(self):
         return Vector2(self.x,self.y)
         
@@ -125,7 +131,7 @@ class Menu_Manager(object):
         exit()
 
 class sprite:
-    def __init__(self,name,path,isactive,layer):
+    def __init__(self,name,path,isactive=True,layer=0):
         self.name = name
         self.file = path
         self.position = Vector2(0,0)
@@ -596,7 +602,7 @@ class Menu:
         decorateur qui ajoute automatiquement le retour de la fonction à la liste
         """
         _sprite = func()
-        if _sprite.__class__.__base__ == sprite:
+        if sprite in _sprite.__class__.__bases__ or type(_sprite)==sprite:
             self.sprites.append(_sprite)
         else:
             raise TypeError("You must return a sprite based class to add, type returned was :",type(_sprite))
